@@ -1,13 +1,12 @@
-# $Id$
+# $Id: Server.pm,v 1.2 2003/12/28 05:37:48 btrott Exp $
 
 package XML::Atom::Server;
 use strict;
 
-use XML::Atom;
 use base qw( XML::Atom::ErrorHandler );
-use MIME::Base64 qw( encode_base64 decode_base64 );
+use MIME::Base64 qw( encode_base64 );
 use Digest::SHA1 qw( sha1 );
-use XML::Atom::Util qw( first encode_xml textValue );
+use XML::Atom::Util qw( first encode_xml );
 use XML::Atom::Entry;
 
 use constant NS_SOAP => 'http://schemas.xmlsoap.org/soap/envelope/';
@@ -60,7 +59,7 @@ sub run {
     }
     my $out;
     eval {
-        defined($out = $server->handle_request) or die $server->errstr;
+        $out = $server->handle_request or die $server->errstr;
         if (defined $out && $server->{is_soap}) {
             $out =~ s!^(<\?xml.*?\?>)!!;
             $out = <<SOAP;
@@ -227,7 +226,6 @@ sub show_error {
 FAULT
     } else {
         return <<ERR;
-<?xml version="1.0" encoding="utf-8"?>
 <error>$err</error>
 ERR
     }
@@ -264,12 +262,12 @@ sub authenticate {
         return $server->auth_failure(400, "X-WSSE requires $f")
             unless $auth->{$f};
     }
-    my $password = $server->password_for_user($auth->{Username});
-    defined($password) or return $server->auth_failure(403, 'Invalid login');
+    my $password = $server->password_for_user($auth->{Username})
+        or return $server->auth_failure(403, 'Invalid login');
     my $expected = encode_base64(sha1(
-           decode_base64($auth->{Nonce}) . $auth->{Created} . $password
+           $auth->{Nonce} . $auth->{Created} . $password
     ), '');
-    return $server->auth_failure(403, 'Invalid login')
+    return $server->auth_failure(403, 'X-WSSE PasswordDigest is incorrect')
         unless $expected eq $auth->{PasswordDigest};
     return 1;
 }
@@ -283,14 +281,8 @@ sub auth_failure {
 sub xml_body {
     my $server = shift;
     unless (exists $server->{xml_body}) {
-        if (LIBXML) {
-            my $parser = XML::LibXML->new;
-            $server->{xml_body} =
-                $parser->parse_string($server->request_content);
-        } else {
-            $server->{xml_body} =
-                XML::XPath->new(xml => $server->request_content);
-        }
+        my $parser = XML::LibXML->new;
+        $server->{xml_body} = $parser->parse_string($server->request_content);
     }
     $server->{xml_body};
 }
@@ -323,7 +315,7 @@ XML::Atom::Server - A server for the Atom API
     sub handle_request {
         my $server = shift;
         $server->authenticate or return;
-        my $method = $server->request_method;
+        my $method = $app->request_method;
         if ($method eq 'POST') {
             return $server->new_post;
         }
@@ -385,7 +377,7 @@ For example:
         my $server = shift;
         my $entry = $server->atom_body or return;
         my $id = save_this_entry($entry);  ## Implementation-specific
-        $server->response_header(Location => $server->uri . '/entry_id=' . $id);
+        $server->response_header(Location => $app->uri . '/entry_id=' . $id);
         $server->response_code(201);
         $server->response_content_type('application/x.atom+xml');
         return serialize_entry($entry);    ## Implementation-specific
@@ -398,8 +390,7 @@ feeds should override the I<password_for_user> method. Given a username
 (from the WSSE header), I<password_for_user> should return that user's
 password in plaintext. This will then be combined with the nonce and the
 creation time to generate the digest, which will be compared with the
-digest sent in the WSSE header. If the supplied username doesn't exist in
-your user database or alike, just return C<undef>.
+digest sent in the WSSE header.
 
 For example:
 
